@@ -3,12 +3,16 @@ import validations
 from Table import *
 from ModuleAuth import *
 
+NOTE_PASSWD = "Full path to the Htpasswd formated password file."
+
 DATA_VALIDATION = [
     ('vserver!.*?!(directory|extensions|request)!.*?!passwdfile', 
      (validations.is_local_file_exists, 'cfg'))
 ]
 
-NOTE_PASSWD = "Full path to the Htpasswd formated password file."
+HELPS = [
+    ('modules_validators_htpasswd', "Htpasswd")
+]
 
 class ModuleHtpasswd (ModuleAuthBase):
     PROPERTIES = ModuleAuthBase.PROPERTIES + [
