@@ -1,20 +1,25 @@
 from Form import *
 from Table import *
-from Module import *
+from ModuleHandler import *
 from consts import *
 
 NOTE_SHOW         = "Defines whether the redirection will be seen by the client."
 NOTE_REGEX        = "Regular expression. Check out the <a target=\"_blank\" href=\"http://perldoc.perl.org/perlre.html\">Reference</a>."
 NOTE_SUBSTITUTION = "Target address. It can use Regular Expression substitution sub-strings."
 
-class ModuleRedir (Module, FormHelper):
+HELPS = [
+    ('modules_handlers_redir',              "Redirections"),
+    ('http://perldoc.perl.org/perlre.html', "Regular Expressions")
+]
+
+class ModuleRedir (ModuleHandler):
     PROPERTIES = [
         "rewrite"
     ]
 
     def __init__ (self, cfg, prefix, submit_url):
-        Module.__init__ (self, 'redir', cfg, prefix, submit_url)
-        FormHelper.__init__ (self, 'redir', cfg)
+        ModuleHandler.__init__ (self, 'redir', cfg, prefix, submit_url)
+        self.show_document_root = False
 
     def _op_render (self):
         cfg_key = "%s!rewrite" % (self._prefix)
@@ -29,7 +34,8 @@ class ModuleRedir (Module, FormHelper):
             for rule in cfg:
                 cfg_key_rule = "%s!%s" % (cfg_key, rule)
 
-                show, _,_ = self.InstanceOptions ('%s!show'%(cfg_key_rule), REDIR_SHOW)
+                js = "this.form.submit()"
+                show, _,_ = self.InstanceOptions ('%s!show'%(cfg_key_rule), REDIR_SHOW, onChange=js)
                 regex     = self._cfg.get_val('%s!regex'    %(cfg_key_rule))
                 substring = self._cfg.get_val('%s!substring'%(cfg_key_rule))
                 js = "post_del_key('/ajax/update', '%s');" % (cfg_key_rule)
@@ -42,8 +48,8 @@ class ModuleRedir (Module, FormHelper):
         # Add new rule
         table = TableProps()
         self.AddPropOptions (table, 'Show', "rewrite_new_show", REDIR_SHOW, NOTE_SHOW)
-        self.AddPropEntry   (table, 'Regular Expression', 'rewrite_new_regex', NOTE_REGEX)
-        self.AddPropEntry   (table, 'Substitution', 'rewrite_new_substring', NOTE_SUBSTITUTION)
+        self.AddPropEntry   (table, 'Regular Expression', 'rewrite_new_regex', NOTE_REGEX, req=True)
+        self.AddPropEntry   (table, 'Substitution', 'rewrite_new_substring', NOTE_SUBSTITUTION, req=True)
 
         txt += "<h2>Add new rule</h2>"
         txt += self.Indent(table)
@@ -54,7 +60,7 @@ class ModuleRedir (Module, FormHelper):
         while True:
             key = "%s!rewrite!%d" % (self._prefix, i)
             tmp = self._cfg[key]
-            if not tmp: 
+            if not tmp:
                 return str(i)
             i += 1
 
