@@ -1,3 +1,4 @@
+import copy
 import types
 
 class ConfigNode (object):
@@ -6,6 +7,7 @@ class ConfigNode (object):
         self._child = {}
 
     # Value
+    #
     def _get_value (self):
         return self._val
     def _set_value (self, val):
@@ -181,6 +183,19 @@ class Config:
     def __getitem__ (self, path):
         return self.root[path]
 
+    def clone (self, path_old, path_new):
+        parent, parent_path, child_name = self._get_parent_node (path_old)
+        if self.root[path_new]:
+            return True
+        copied = copy.deepcopy (self[path_old])
+        self.set_sub_node (path_new, copied)
+    
+    def rename (self, path_old, path_new):
+        error = self.clone (path_old, path_new)
+        if not error:
+            del(self[path_old])
+        return error
+
     def set_sub_node (self, path, config_node):
         assert (isinstance(config_node, ConfigNode))
 
@@ -216,9 +231,49 @@ class Config:
         if parent and parent._child.has_key(child_name):
             del (parent._child[child_name])
 
+    def keys (self, path):
+        tmp = self[path]
+        if not tmp:
+            return []
+        return tmp.keys()
+
+    def pop (self, key):
+        tmp = self.get_val(key)
+        del (self[key])
+        return tmp
+
     # Serialization
     def serialize (self):
-        return self.root.serialize()
+        def sorter(x,y):
+            order = ['server', 'vserver', 'source', 'icons', 'mime']
+            a = x.split('!')
+            b = y.split('!')
+            try:
+                ai = order.index(a[0])
+                bi = order.index(b[0])
+            except:
+                return cmp(x,y)
+
+            # Different tags
+            if ai > bi:
+                return  1
+            elif ai < bi:
+                return -1
+
+            # Sort rules: reverse
+            if ((len(a) > 3) and 
+                (a[0] == b[0] == 'vserver') and
+                (a[1] == b[1]) and
+                (a[2] == b[2] == 'rule')):
+                re = cmp (int(b[3]), int(a[3]))
+                if re != 0:
+                    return re
+
+            return cmp(x,y)
+
+        tmp = self.root.serialize().split('\n')
+        tmp.sort(sorter)
+        return '\n'.join(tmp)
 
     def save (self):
         # Try to make a copy
