@@ -87,6 +87,13 @@
 	 (size_t)(((struct sockaddr_un*)0)->sun_path))
 #endif
 
+#ifndef OPENSSL_NO_TLSEXT
+# ifndef SSL_CTRL_SET_TLSEXT_HOSTNAME
+#  define OPENSSL_NO_TLSEXT
+# endif
+#endif
+
+
 /* Socket status
  */
 typedef enum {
@@ -185,11 +192,13 @@ ret_t cherokee_socket_mrproper          (cherokee_socket_t *socket);
 ret_t cherokee_socket_clean             (cherokee_socket_t *socket);
 
 ret_t cherokee_socket_init_tls          (cherokee_socket_t *socket, cherokee_virtual_server_t *vserver);
-ret_t cherokee_socket_init_client_tls   (cherokee_socket_t *socket);
+ret_t cherokee_socket_init_client_tls   (cherokee_socket_t *socket, cherokee_buffer_t *host);
 
 ret_t cherokee_socket_close             (cherokee_socket_t *socket);
 ret_t cherokee_socket_shutdown          (cherokee_socket_t *socket, int how);
 ret_t cherokee_socket_accept            (cherokee_socket_t *socket, int server_socket);
+int   cherokee_socket_pending_read      (cherokee_socket_t *socket);
+ret_t cherokee_socket_flush             (cherokee_socket_t *socket);
 
 ret_t cherokee_socket_set_client        (cherokee_socket_t *socket, unsigned short int type);
 ret_t cherokee_socket_bind              (cherokee_socket_t *socket, int port, cherokee_buffer_t *listen_to);
