@@ -3,21 +3,21 @@ from base import *
 MAGIC = "Cherokee_is_pure_magic"
 
 CONF = """
-vserver!default!rule!1150!match = directory
-vserver!default!rule!1150!match!directory = /respin1
-vserver!default!rule!1150!handler = common
+vserver!1!rule!1150!match = directory
+vserver!1!rule!1150!match!directory = /respin1
+vserver!1!rule!1150!handler = common
 
-vserver!default!rule!1151!match = directory
-vserver!default!rule!1151!match!directory = /respin1-cgi
-vserver!default!rule!1151!handler = phpcgi
-vserver!default!rule!1151!handler!interpreter = %s
+vserver!1!rule!1151!match = directory
+vserver!1!rule!1151!match!directory = /respin1-cgi
+vserver!1!rule!1151!handler = phpcgi
+vserver!1!rule!1151!handler!interpreter = %s
 
-vserver!default!rule!1152!match = request
-vserver!default!rule!1152!match!request = /respin1/.+/
-vserver!default!rule!1152!handler = redir
-vserver!default!rule!1152!handler!rewrite!1!show = 0
-vserver!default!rule!1152!handler!rewrite!1!regex = ^/respin1/(.+)/$
-vserver!default!rule!1152!handler!rewrite!1!substring = /respin1-cgi/file?param=$1
+vserver!1!rule!1152!match = request
+vserver!1!rule!1152!match!request = /respin1/.+/
+vserver!1!rule!1152!handler = redir
+vserver!1!rule!1152!handler!rewrite!1!show = 0
+vserver!1!rule!1152!handler!rewrite!1!regex = ^/respin1/(.+)/$
+vserver!1!rule!1152!handler!rewrite!1!substring = /respin1-cgi/file?param=$1
 """
 
 class Test (TestBase):
